.v-input__slot{-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center}.modelNavList .modelItem .action{display:none}.modelNavList .modelItem:hover .action{display:block}.modelNavList .modelItem .icon{display:-webkit-box;display:-ms-flexbox;display:flex;margin-bottom:0}.modelNavList .modelItem:hover .icon,.projectNavList .projectItem .action{display:none}.projectNavList .projectItem:hover .action{display:block}.navigation .flex{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;height:100%}.navigation .nav-item{font-size:9px;text-align:center;width:100%}.navigation .resize-handle{cursor:ew-resize;height:100%;position:fixed;right:0;width:4px;z-index:10}.backendStatus{height:18px;line-height:18px}@media print{.no-print{display:none!important}.print{display:block!important}.v-main{padding:0!important}@page{size:landscape}}.v-toast__text h1{font-size:20px}.v-toast__text p{margin:4px 0}.fade-enter-active{-webkit-transition:opacity .5s;transition:opacity .5s}.fade-enter,.fade-leave-active{opacity:0}.ma-1px{margin:1px!important}.ma-2px{margin:2px!important}.paramLabel,.v-tabs-slider-wrapper{pointer-events:none}.paramLabel{color:#000;font-size:12px;font-weight:400;height:12px;left:-8px;line-height:12px;position:absolute;top:2px}.nest.icon #background{fill-opacity:1;fill-rule:nonzero;fill:currentColor;stroke-width:.241823;stroke:none}.nest.icon path.content{-inkscape-font-specification:"Courier 10 Pitch Bold";fill-opacity:1;fill:#fff;font-family:Courier\ 10 Pitch;font-size:74px;font-stretch:normal;font-style:normal;font-variant:normal;font-weight:700;letter-spacing:-2.5px;line-height:0;stroke-width:.241823;stroke:none;text-align:start;text-anchor:start;word-spacing:0;-webkit-writing-mode:lr-tb;-ms-writing-mode:lr-tb;writing-mode:lr-tb}.nest.icon circle.content{fill-opacity:1;fill:#fff;stroke-width:.17476;stroke:none}.theme--dark .nest.icon #background{fill:none}.theme--dark .nest.icon .content{fill:currentColor}.network.icon path{fill:none;stroke-width:1.8;stroke:currentColor}