.modelEditor{height:calc(100vh - 72px);overflow-y:auto}.modelView{height:100vh;overflow-y:hidden}.modelView .nav-controller>.v-navigation-drawer__content{margin-right:64px}.modelView .controller{width:100%}.modelView .nav-item-right{font-size:9px;text-align:center;width:100%}.modelView .resize-handle{cursor:ew-resize;height:100%;left:0;position:fixed;width:4px;z-index:10}.modelView .tab-text{font-size:10px;margin-bottom:2px!important}