.appDetails .v-list{font-size:12px}.appDetails .v-list-item{min-height:28px!important}.appDetails a:hover{text-decoration:underline!important}.appDetails .col-4,.appDetails .col-8{padding:4px}.appInfo .logo{overflow:hidden}.appInfo .logo .v-image{-webkit-transition:all .5s ease-in-out;transition:all .5s ease-in-out;-webkit-transform:scale(1);transform:scale(1)}.appInfo .logo:hover .v-image{-webkit-transform:scale(1.5);transform:scale(1.5)}.v-main{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-flex:1;-ms-flex:1 0 auto;flex:1 0 auto;max-width:100%;-webkit-transition:.2s cubic-bezier(.4,0,.2,1);transition:.2s cubic-bezier(.4,0,.2,1)}.v-main:not([data-booted=true]){-webkit-transition:none!important;transition:none!important}.v-main__wrap{-webkit-box-flex:1;-ms-flex:1 1 auto;flex:1 1 auto;max-width:100%;position:relative}@-moz-document url-prefix(){@media print{.v-main{display:block}}}